@@ -103,11 +103,15 @@ def stream_sqlite(sqlite_chunks):
             yield page_num, page_bytes, page_reader
 
     def yield_table_pages(page_nums_pages_readers, first_freelist_trunk_page):
+        # Map of page number -> bytes. Populated when we reach a page that
+        # can't be identified and so can't be processed.
         page_buffer = {}
-        page_types = {}
-        master_table = {}
 
-        def process_table_page(table_name, page_bytes, page_reader):
+        # Map of page number -> page processor function. Populated when we
+        # identify a page, but don't have it in the buffer yet.
+        page_processors = {}
+
+        def process_table_page(table_name, table_info, page_bytes, page_reader):
 
             def get_master_table(master_cells):
 
@@ -174,18 +178,16 @@ def stream_sqlite(sqlite_chunks):
 
                 pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
                 for table_or_index, table_name, table_info, root_page in get_master_table(yield_leaf_table_cells(pointers)):
-                    if table_or_index == 'table':
-                        master_table[table_name] = table_info
-                        yield from process_if_buffered_or_remember(partial(process_table_page, table_name), root_page)
-                    else:
-                        yield from process_if_buffered_or_remember(partial(process_index_page, table_name), root_page)
+                    yield from (
+                        process_if_buffered_or_remember(partial(process_table_page, table_name, table_info), root_page) if table_or_index == 'table' else \
+                        process_if_buffered_or_remember(process_index_page, root_page)
+                    )
 
             def process_table_leaf_non_master():
                 first_free_block, num_cells, cell_content_start, num_frag_free = \
                     table_leaf_header.unpack(page_reader(7))
 
                 pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
-                table_info = master_table[table_name]
 
                 yield table_name, table_info, (
                     {
@@ -205,10 +207,10 @@ def stream_sqlite(sqlite_chunks):
                     cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
                     page_number, =  unsigned_long.unpack(cell_num_reader(4))
                     yield from process_if_buffered_or_remember(
-                        partial(process_table_page, table_name), page_number)
+                        partial(process_table_page, table_name, table_info), page_number)
 
                 yield from process_if_buffered_or_remember(
-                    partial(process_table_page, table_name), right_most_pointer)
+                    partial(process_table_page, table_name, table_info), right_most_pointer)
 
             page_type = page_reader(1)
             yield from (
@@ -217,7 +219,7 @@ def stream_sqlite(sqlite_chunks):
                 process_table_interior()
             )
 
-        def process_index_page(table_name, page_bytes, page_reader):
+        def process_index_page(page_bytes, page_reader):
 
             def process_index_leaf():
                 yield from ()
@@ -231,11 +233,9 @@ def stream_sqlite(sqlite_chunks):
                 for pointer in pointers:
                     cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
                     page_num, =  unsigned_long.unpack(cell_num_reader(4))
-                    yield from process_if_buffered_or_remember(
-                        partial(process_index_page, table_name), page_num)
+                    yield from process_if_buffered_or_remember(process_index_page, page_num)
 
-                yield from process_if_buffered_or_remember(
-                    partial(process_index_page, table_name), right_most_pointer)
+                yield from process_if_buffered_or_remember(process_index_page, right_most_pointer)
 
             page_type = page_reader(1)
             yield from (
@@ -254,22 +254,22 @@ def stream_sqlite(sqlite_chunks):
                 yield from process_if_buffered_or_remember(process_freelist_trunk_page, next_trunk)
 
         def process_freelist_leaf_page(page_bytes, page_reader):
-            yield from []
+            yield from ()
 
         def process_if_buffered_or_remember(process, page_num):
             try:
                 page_bytes, page_reader = page_buffer.pop(page_num)
             except KeyError:
-                page_types[page_num] = process
+                page_processors[page_num] = process
             else:
                 yield from process(page_bytes, page_reader)
 
-        page_types[1] = partial(process_table_page, 'sqlite_schema')
-        page_types[first_freelist_trunk_page] = process_freelist_trunk_page
+        page_processors[1] = partial(process_table_page, 'sqlite_schema', ())
+        page_processors[first_freelist_trunk_page] = process_freelist_trunk_page
 
         for page_num, page_bytes, page_reader in page_nums_pages_readers:
             try:
-                process_page = page_types.pop(page_num)
+                process_page = page_processors.pop(page_num)
             except KeyError:
                 page_buffer[page_num] = (page_bytes, page_reader)
             else:
